Struct amazon_sp_notifications::models::event_filter::EventFilter
source · [−]pub struct EventFilter {
pub aggregation_settings: Option<Box<AggregationSettings>>,
pub marketplace_ids: Option<Vec<String>>,
pub event_filter_type: String,
}Expand description
EventFilter : A notificationType specific filter. This object contains all of the currently available filters and properties that you can use to define a notificationType specific filter.
Fields
aggregation_settings: Option<Box<AggregationSettings>>marketplace_ids: Option<Vec<String>>A list of marketplace identifiers to subscribe to (e.g. ATVPDKIKX0DER). To receive notifications in every marketplace, do not provide this list.
event_filter_type: StringAn eventFilterType value that is supported by the specific notificationType. This is used by the subscription service to determine the type of event filter. Refer to the section of the Notifications Use Case Guide that describes the specific notificationType to determine if an eventFilterType is supported.
Implementations
sourceimpl EventFilter
impl EventFilter
sourcepub fn new(event_filter_type: String) -> EventFilter
pub fn new(event_filter_type: String) -> EventFilter
A notificationType specific filter. This object contains all of the currently available filters and properties that you can use to define a notificationType specific filter.